@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include "mailcommon_debug.h"
 #include "util/mailutil.h"
 
-#include <AkonadiCore/CollectionModifyJob>
+#include <Akonadi/CollectionModifyJob>
 
 using namespace MailCommon;
 
@@ -17,9 +17,7 @@ CollectionExpiryJob::CollectionExpiryJob(QObject *parent)
 {
 }
 
-CollectionExpiryJob::~CollectionExpiryJob()
-{
-}
+CollectionExpiryJob::~CollectionExpiryJob() = default;
 
 void CollectionExpiryJob::start()
 {
