@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QApplication>
 #include "../filter/dialog/filteractionmissingtransportdialog.h"
+#include <QApplication>
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    MailCommon::FilterActionMissingTransportDialog *w = new MailCommon::FilterActionMissingTransportDialog(QStringLiteral("filename"));
+    auto w = new MailCommon::FilterActionMissingTransportDialog(QStringLiteral("filename"));
     w->exec();
     app.exec();
     delete w;
