@@ -15,14 +15,14 @@ using PimCommon::BroadcastStatus;
 
 #include <KLocalizedString>
 
-#include <Akonadi/KMime/MessageFlags>
-#include <Akonadi/KMime/MessageParts>
-#include <Akonadi/KMime/MessageStatus>
-#include <ItemDeleteJob>
-#include <ItemFetchJob>
-#include <ItemFetchScope>
-#include <ItemModifyJob>
-#include <ItemMoveJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/ItemMoveJob>
+#include <Akonadi/MessageFlags>
+#include <Akonadi/MessageParts>
+#include <Akonadi/MessageStatus>
 #include <KMime/Message>
 
 /*
@@ -61,7 +61,8 @@ void ExpireJob::execute()
 
     const MailCommon::ExpireCollectionAttribute *expirationAttribute = mSrcFolder.attribute<MailCommon::ExpireCollectionAttribute>();
     if (expirationAttribute) {
-        int unreadDays, readDays;
+        int unreadDays;
+        int readDays;
         mExpireMessagesWithoutInvalidDate = expirationAttribute->expireMessagesWithValidDate();
         expirationAttribute->daysToExpire(unreadDays, readDays);
 
