@@ -9,26 +9,26 @@
 
 #include "kernel/mailkernel.h"
 #include "mailcommon_debug.h"
-#include "mdnadvicehelper.h"
 #include "util/mailutil.h"
+#include <MessageComposer/MDNAdviceHelper>
 #include <MessageComposer/MessageFactoryNG>
 #include <MessageComposer/MessageSender>
 #include <MessageComposer/Util>
 #include <MessageViewer/MessageViewerSettings>
 
-#include <Akonadi/KMime/MessageFlags>
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <Akonadi/MessageFlags>
 
 #include <QQueue>
 #include <QTimer>
 
 using namespace MailCommon;
 
-class Q_DECL_HIDDEN SendMdnHandler::Private
+class Q_DECL_HIDDEN SendMdnHandler::SendMdnHandlerPrivate
 {
 public:
-    Private(SendMdnHandler *qq, IKernel *kernel)
+    SendMdnHandlerPrivate(SendMdnHandler *qq, IKernel *kernel)
         : q(qq)
         , mKernel(kernel)
     {
@@ -42,7 +42,7 @@ public:
     QTimer mTimer;
 };
 
-void SendMdnHandler::Private::handleMessages()
+void SendMdnHandler::SendMdnHandlerPrivate::handleMessages()
 {
     while (!mItemQueue.isEmpty()) {
         Akonadi::Item item = mItemQueue.dequeue();
@@ -70,7 +70,7 @@ void SendMdnHandler::Private::handleMessages()
             continue;
         }
 
-        const QPair<bool, KMime::MDN::SendingMode> mdnSend = MDNAdviceHelper::instance()->checkAndSetMDNInfo(item, KMime::MDN::Displayed);
+        const QPair<bool, KMime::MDN::SendingMode> mdnSend = MessageComposer::MDNAdviceHelper::instance()->checkAndSetMDNInfo(item, KMime::MDN::Displayed);
         if (mdnSend.first) {
             const int quote = MessageViewer::MessageViewerSettings::self()->quoteMessage();
 
@@ -90,7 +90,7 @@ void SendMdnHandler::Private::handleMessages()
 
 SendMdnHandler::SendMdnHandler(IKernel *kernel, QObject *parent)
     : QObject(parent)
-    , d(new Private(this, kernel))
+    , d(new SendMdnHandlerPrivate(this, kernel))
 {
     d->mTimer.setSingleShot(true);
     connect(&d->mTimer, &QTimer::timeout, this, [this]() {
@@ -98,10 +98,7 @@ SendMdnHandler::SendMdnHandler(IKernel *kernel, QObject *parent)
     });
 }
 
-SendMdnHandler::~SendMdnHandler()
-{
-    delete d;
-}
+SendMdnHandler::~SendMdnHandler() = default;
 
 void SendMdnHandler::setItem(const Akonadi::Item &item)
 {
